summaryrefslogtreecommitdiffstats
path: root/Graphics/GraphicsEngine
diff options
context:
space:
mode:
Diffstat (limited to 'Graphics/GraphicsEngine')
-rw-r--r--Graphics/GraphicsEngine/interface/GraphicsTypes.h26
1 files changed, 10 insertions, 16 deletions
diff --git a/Graphics/GraphicsEngine/interface/GraphicsTypes.h b/Graphics/GraphicsEngine/interface/GraphicsTypes.h
index d7af003b..b2e53a16 100644
--- a/Graphics/GraphicsEngine/interface/GraphicsTypes.h
+++ b/Graphics/GraphicsEngine/interface/GraphicsTypes.h
@@ -1308,19 +1308,21 @@ namespace Diligent
/// Debug flags that can be specified when creating Direct3D11-based engine implementation.
///
/// \sa CreateDeviceAndContextsD3D11Type, CreateSwapChainD3D11Type, LoadGraphicsEngineD3D11
- enum class EngineD3D11DebugFlags : Uint32
+ enum D3D11_DEBUG_FLAGS : Uint32
{
+ /// No debug flag
+ D3D11_DEBUG_FLAG_NONE = 0x00,
+
/// Before executing draw/dispatch command, verify that
/// all required shader resources are bound to the device context
- VerifyCommittedShaderResources = 0x01,
+ D3D11_DEBUG_FLAG_VERIFY_COMMITTED_SHADER_RESOURCES = 0x01,
/// Verify that all committed cotext resources are relevant,
/// i.e. they are consistent with the committed resource cache.
- /// This is very expensive operation and should generally not be
- /// necessary.
- VerifyCommittedResourceRelevance = 0x02
+ /// This is very expensive and should generally not be necessary.
+ D3D11_DEBUG_FLAG_VERIFY_COMMITTED_RESOURCE_RELEVANCE = 0x02
};
-
+ DEFINE_FLAG_ENUM_OPERATORS(D3D11_DEBUG_FLAGS)
/// Direct3D11/12 feature level
enum DIRECT3D_FEATURE_LEVEL : Uint8
@@ -1355,18 +1357,10 @@ namespace Diligent
/// Minimum required Direct3D feature level.
DIRECT3D_FEATURE_LEVEL MinimumFeatureLevel = DIRECT3D_FEATURE_LEVEL_11_0;
/// Debug flags. See Diligent::EngineD3D11DebugFlags for a list of allowed values.
///
/// \sa CreateDeviceAndContextsD3D11Type, CreateSwapChainD3D11Type, LoadGraphicsEngineD3D11
- Uint32 DebugFlags;
-
- EngineD3D11CreateInfo() :
- DebugFlags(0)
- {
-#ifdef _DEBUG
- DebugFlags = static_cast<Uint32>(EngineD3D11DebugFlags::VerifyCommittedShaderResources);
-#endif
- }
+ D3D11_DEBUG_FLAGS DebugFlags = D3D11_DEBUG_FLAG_NONE;
};
/// Attributes specific to D3D12 engine
@@ -1355,18 +1357,10 @@ namespace Diligent
/// Minimum required Direct3D feature level.
DIRECT3D_FEATURE_LEVEL MinimumFeatureLevel = DIRECT3D_FEATURE_LEVEL_11_0;
- /// Debug flags. See Diligent::EngineD3D11DebugFlags for a list of allowed values.
+ /// Debug flags. See Diligent::D3D11_DEBUG_FLAGS for a list of allowed values.
///
/// \sa CreateDeviceAndContextsD3D11Type, CreateSwapChainD3D11Type, LoadGraphicsEngineD3D11